DCATR.DataGraph (DCAT-R.ex v0.1.0)

Copy Markdown View Source

A DCATR.Graph containing user data within a DCATR.Dataset.

Data graphs form the primary content of the repository's dataset - the actual domain data. They are always contained in the dataset catalog and distributed with the repository.

Summary

Types

t()

@type t() :: %DCATR.DataGraph{__additional_statements__: term(), __id__: term()}

Functions

build(id)

build(id, initial)

build!(id)

build!(id, initial)

build_id(attributes)

from(value)

@spec from(Grax.Schema.t()) :: {:ok, t()} | {:error, any()}

from!(value)

@spec from!(Grax.Schema.t()) :: t()

load(graph, id, opts \\ [])

@spec load(
  RDF.Graph.t() | RDF.Description.t(),
  RDF.IRI.coercible() | RDF.BlankNode.t(),
  opts :: keyword()
) :: {:ok, t()} | {:error, any()}

load!(graph, id, opts \\ [])

@spec load!(
  RDF.Graph.t() | RDF.Description.t(),
  RDF.IRI.coercible() | RDF.BlankNode.t(),
  opts :: keyword()
) :: t()

new(id, attrs \\ [])

new!(id, attrs \\ [])