Abstract base schema for items that can be organized within a DCATR.Directory.
Both DCATR.Graph and DCATR.Directory inherit from this schema, enabling
hierarchical containment where directories can hold graphs and nested directories.
Summary
Types
Functions
@spec from(Grax.Schema.t()) :: {:ok, t()} | {:error, any()}
@spec from!(Grax.Schema.t()) :: t()
@spec load( RDF.Graph.t() | RDF.Description.t(), RDF.IRI.coercible() | RDF.BlankNode.t(), opts :: keyword() ) :: {:ok, t()} | {:error, any()}
@spec load!( RDF.Graph.t() | RDF.Description.t(), RDF.IRI.coercible() | RDF.BlankNode.t(), opts :: keyword() ) :: t()