A DCATR.ManifestGraph containing instance-specific configuration of a DCATR.Service.
Service manifest graphs contain service-specific configuration and local settings. These graphs are not replicated between service instances and contain the local configuration specific to one service instance.
Blank nodes are allowed as graph IDs for service manifest graphs.
Summary
Types
Functions
@spec from(Grax.Schema.t()) :: {:ok, t()} | {:error, any()}
@spec from!(Grax.Schema.t()) :: t()
@spec load( RDF.Graph.t() | RDF.Description.t(), RDF.IRI.coercible() | RDF.BlankNode.t(), opts :: keyword() ) :: {:ok, t()} | {:error, any()}
@spec load!( RDF.Graph.t() | RDF.Description.t(), RDF.IRI.coercible() | RDF.BlankNode.t(), opts :: keyword() ) :: t()