A DCATR.Graph for temporary, service-local working areas.
Working graphs are never distributed. They serve as staging areas, draft spaces, caches, or experimental work areas - analogous to a working directory in version control systems.
Blank nodes are allowed as graph IDs for working graphs.
Summary
Types
Functions
@spec from(Grax.Schema.t()) :: {:ok, t()} | {:error, any()}
@spec from!(Grax.Schema.t()) :: t()
@spec load( RDF.Graph.t() | RDF.Description.t(), RDF.IRI.coercible() | RDF.BlankNode.t(), opts :: keyword() ) :: {:ok, t()} | {:error, any()}
@spec load!( RDF.Graph.t() | RDF.Description.t(), RDF.IRI.coercible() | RDF.BlankNode.t(), opts :: keyword() ) :: t()